
**Naked** is a new Python command line application framework that is in active development.  The current release is a stable, testing release.

Documentation is in development at `http://docs.naked-py.com/ <http://docs.naked-py.com/>`_

Issue reporting is available on the `GitHub repository <http://github.com/chrissimpkins/naked/issues>`_

Applications that are currently testing the Naked framework include:

• `status <http://pypi.python.org/status>`_

I would greatly appreciate feedback from anyone who is interested in testing the framework.  Feel free to contact me on Twitter (@csimpkins) if you have questions, comments, or problems.  Please use the issue reporting link above for bug reports.
